# Environment Variables

vLLM Spyre uses the following environment variables to configure the system:

:::{literalinclude} ../../../vllm_spyre/envs.py
:end-before: end-env-vars-definition
:language: python
:start-after: begin-env-vars-definition
:::
